pilot.api.data.api.PilotData

Package pilot :: Package api :: Package data :: Module api :: Class PilotData |

# Class PilotData

source code

PilotData (PD).

Instance Methods
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
cancel(self) Cancel PilotData | source code
get_state(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
| context
| description
| id
| resource_url
| state
| state_detail
Inherited from `object`: `__class__`

Method Details

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### cancel(self) | source code
Cancel PilotData Keyword arguments: None